@@ -1,9 +1,11 @@
 package # hide from PAUSE
     MooseX::Declare::StackItem;
 
+our $VERSION = '0.42';
+
 use Moose;
 
-use namespace::clean -except => 'meta';
+use namespace::autoclean;
 use overload '""' => 'as_string', fallback => 1;
 
 has identifier => (
